# coding: utf-8

"""
    shado-python-client

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from shado_client.models.object_id import ObjectID  # noqa: F401,E501


class Sharing(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'created_at': 'datetime',
        'id': 'ObjectID',
        'owner_id': 'ObjectID',
        'item_id': 'ObjectID',
        'group_id': 'ObjectID',
        'result_id': 'ObjectID'
    }

    attribute_map = {
        'created_at': 'createdAt',
        'id': 'id',
        'owner_id': 'ownerId',
        'item_id': 'itemId',
        'group_id': 'groupId',
        'result_id': 'resultId'
    }

    def __init__(self, created_at=None, id=None, owner_id=None, item_id=None, group_id=None, result_id=None):  # noqa: E501
        """Sharing - a model defined in Swagger"""  # noqa: E501

        self._created_at = None
        self._id = None
        self._owner_id = None
        self._item_id = None
        self._group_id = None
        self._result_id = None
        self.discriminator = None

        if created_at is not None:
            self.created_at = created_at
        if id is not None:
            self.id = id
        if owner_id is not None:
            self.owner_id = owner_id
        if item_id is not None:
            self.item_id = item_id
        if group_id is not None:
            self.group_id = group_id
        if result_id is not None:
            self.result_id = result_id

    @property
    def created_at(self):
        """Gets the created_at of this Sharing.  # noqa: E501


        :return: The created_at of this Sharing.  # noqa: E501
        :rtype: datetime
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """Sets the created_at of this Sharing.


        :param created_at: The created_at of this Sharing.  # noqa: E501
        :type: datetime
        """

        self._created_at = created_at

    @property
    def id(self):
        """Gets the id of this Sharing.  # noqa: E501


        :return: The id of this Sharing.  # noqa: E501
        :rtype: ObjectID
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this Sharing.


        :param id: The id of this Sharing.  # noqa: E501
        :type: ObjectID
        """

        self._id = id

    @property
    def owner_id(self):
        """Gets the owner_id of this Sharing.  # noqa: E501


        :return: The owner_id of this Sharing.  # noqa: E501
        :rtype: ObjectID
        """
        return self._owner_id

    @owner_id.setter
    def owner_id(self, owner_id):
        """Sets the owner_id of this Sharing.


        :param owner_id: The owner_id of this Sharing.  # noqa: E501
        :type: ObjectID
        """

        self._owner_id = owner_id

    @property
    def item_id(self):
        """Gets the item_id of this Sharing.  # noqa: E501


        :return: The item_id of this Sharing.  # noqa: E501
        :rtype: ObjectID
        """
        return self._item_id

    @item_id.setter
    def item_id(self, item_id):
        """Sets the item_id of this Sharing.


        :param item_id: The item_id of this Sharing.  # noqa: E501
        :type: ObjectID
        """

        self._item_id = item_id

    @property
    def group_id(self):
        """Gets the group_id of this Sharing.  # noqa: E501


        :return: The group_id of this Sharing.  # noqa: E501
        :rtype: ObjectID
        """
        return self._group_id

    @group_id.setter
    def group_id(self, group_id):
        """Sets the group_id of this Sharing.


        :param group_id: The group_id of this Sharing.  # noqa: E501
        :type: ObjectID
        """

        self._group_id = group_id

    @property
    def result_id(self):
        """Gets the result_id of this Sharing.  # noqa: E501


        :return: The result_id of this Sharing.  # noqa: E501
        :rtype: ObjectID
        """
        return self._result_id

    @result_id.setter
    def result_id(self, result_id):
        """Sets the result_id of this Sharing.


        :param result_id: The result_id of this Sharing.  # noqa: E501
        :type: ObjectID
        """

        self._result_id = result_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Sharing):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
